// java wrapper for vtkMoleculeToPolyDataFilter object
//

package vtk;
import vtk.*;

public class vtkMoleculeToPolyDataFilter extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetInput_2();
  public vtkMolecule GetInput() {
    long temp = GetInput_2();

    if (temp == 0) return null;
    return (vtkMolecule)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkMoleculeToPolyDataFilter() { super(); }

  public vtkMoleculeToPolyDataFilter(long id) { super(id); }

}
